==> portal-contribuinte-1.047.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/mobile/findPropriedadeComDebitoEmAbertoPorPeriodo.sql <==
select ger.tipocadastro,
       ger.cadastrogeral,
       pes.pessoa,
       pes.nome,
       pes.cnpj_cpf as cpfCnpj,
       deb.iddebito,
       guia.descricao,
       par.parcela,
       par.datavencimento,
       (select sum(valor)
        from tribdebitoparcelareceita rec
        where rec.entidade       = par.entidade
        and rec.exercicio        = par.exercicio
        and rec.tipocadastro     = par.tipocadastro
        and rec.cadastrogeral    = par.cadastrogeral
        and rec.guiarecolhimento = par.guiarecolhimento
        and rec.subdivida        = par.subdivida
        and rec.parcela          = par.parcela) as valor
from pessoa pes
inner join tribproprietario prop on prop.pessoa = pes.pessoa
inner join tribcadastrogeral ger on ger.tipocadastro  = prop.tipocadastro
                                and ger.cadastrogeral = prop.cadastrogeral
inner join tribdebito deb on deb.tipocadastro = ger.tipocadastro
                          and deb.cadastrogeral = ger.cadastrogeral
inner join tribguiarecolhimento guia on guia.entidade = deb.entidade
                                    and guia.exercicio = deb.exercicio
                                    and guia.guiarecolhimento = deb.guiarecolhimento
inner join tribdebitoparcela par on par.entidade         = deb.entidade
                                and par.exercicio        = deb.exercicio
                                and par.tipocadastro     = deb.tipocadastro
                                and par.cadastrogeral    = deb.cadastrogeral
                                and par.guiarecolhimento = deb.guiarecolhimento
                                and par.subdivida        = deb.subdivida
inner join tribsituacaoparcela sit on sit.situacaoparcela = par.situacaodebito
inner join tribtiposituacaoparcela tip on tip.tiposituacaoparcela = sit.situacaoparcela
where pes.cnpj_cpf      = ?
and   deb.constituido   = 'S'
and   tip.tipo          = 'A'

==> portal-contribuinte-1.053.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/mobile/findPropriedadeComDebitoEmAbertoPorPeriodo.sql <==
select ger.tipocadastro,
       ger.cadastrogeral,
       pes.pessoa,
       pes.nome,
       pes.cnpj_cpf as cpfCnpj,
       deb.iddebito,
       guia.descricao,
       par.parcela,
       par.datavencimento,
       (select sum(valor)
        from tribdebitoparcelareceita rec
        where rec.entidade       = par.entidade
        and rec.exercicio        = par.exercicio
        and rec.tipocadastro     = par.tipocadastro
        and rec.cadastrogeral    = par.cadastrogeral
        and rec.guiarecolhimento = par.guiarecolhimento
        and rec.subdivida        = par.subdivida
        and rec.parcela          = par.parcela) as valor
from pessoa pes
inner join (select p.pessoa, p.cnpj_cpf, a.tipocadastro, a.cadastrogeral
            from pessoa p
            inner join tribrepresentantelegal a on p.pessoa = a.pessoa
            left join tribtiporepresentante b on a.tiporepresentante = b.tiporepresentante and b.administrador = 'S'
            union
            select p.pessoa, p.cnpj_cpf, a.tipocadastro, a.cadastrogeral
            from pessoa p
            inner join tribproprietario a on p.pessoa = a.pessoa) cad on pes.pessoa = cad.pessoa 
                                                                     and pes.cnpj_cpf = cad.cnpj_cpf
inner join tribcadastrogeral ger on ger.tipocadastro  = cad.tipocadastro
                                and ger.cadastrogeral = cad.cadastrogeral
inner join tribdebito deb on deb.tipocadastro = ger.tipocadastro
                          and deb.cadastrogeral = ger.cadastrogeral
inner join tribguiarecolhimento guia on guia.entidade = deb.entidade
                                    and guia.exercicio = deb.exercicio
                                    and guia.guiarecolhimento = deb.guiarecolhimento
inner join tribdebitoparcela par on par.entidade         = deb.entidade
                                and par.exercicio        = deb.exercicio
                                and par.tipocadastro     = deb.tipocadastro
                                and par.cadastrogeral    = deb.cadastrogeral
                                and par.guiarecolhimento = deb.guiarecolhimento
                                and par.subdivida        = deb.subdivida
inner join tribsituacaoparcela sit on sit.situacaoparcela = par.situacaodebito
inner join tribtiposituacaoparcela tip on tip.tiposituacaoparcela = sit.situacaoparcela
where pes.cnpj_cpf      = ?
and   deb.constituido   = 'S'
and   tip.tipo          = 'A'
